==> azureus_2.2.0.2.orig.tar.gz: azureus-2.2.0.2.orig/org/gudy/azureus2/core3/torrent/impl/TOTorrentAnnounceURLGroupImpl.java <==
/*
 * File    : TOTorrentAnnounceURLGroupImpl.java
 * Created : 5 Oct. 2003
 * By      : Parg 
 * 
 * Azureus - a Java Bittorrent client
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.gudy.azureus2.core3.torrent.impl;

import java.net.URL;

import org.gudy.azureus2.core3.torrent.*;

public class 
TOTorrentAnnounceURLGroupImpl
	implements TOTorrentAnnounceURLGroup 
{
	protected TOTorrentAnnounceURLSet[]		sets;
	
	protected
	TOTorrentAnnounceURLGroupImpl()
	{
		sets = new TOTorrentAnnounceURLSet[0];
	}

	protected void
	addSet(
		TOTorrentAnnounceURLSet	set )
	{
		TOTorrentAnnounceURLSet[]	new_sets = new TOTorrentAnnounceURLSet[sets.length+1];
		
		System.arraycopy( sets, 0, new_sets, 0, sets.length );
		
		new_sets[new_sets.length-1] = set;
		
		sets = new_sets;
	}
	
	public TOTorrentAnnounceURLSet[]
	getAnnounceURLSets()
	{
		return( sets );
	}
	
	public void
	setAnnounceURLSets(
		TOTorrentAnnounceURLSet[]	_sets )
	{
		sets = _sets;	
	}
		
	
	public TOTorrentAnnounceURLSet
	createAnnounceURLSet(
		URL[]	urls )
	{
		return( new TOTorrentAnnounceURLSetImpl( urls ));	
	}
	
}

==> azureus_4.3.0.6.orig.tar.gz: azureus-4.3.0.6/org/gudy/azureus2/core3/torrent/impl/TOTorrentAnnounceURLGroupImpl.java <==
/*
 * File    : TOTorrentAnnounceURLGroupImpl.java
 * Created : 5 Oct. 2003
 * By      : Parg 
 * 
 * Azureus - a Java Bittorrent client
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.gudy.azureus2.core3.torrent.impl;

import java.net.URL;

import org.gudy.azureus2.core3.torrent.*;

public class 
TOTorrentAnnounceURLGroupImpl
	implements TOTorrentAnnounceURLGroup 
{
	private TOTorrentImpl	torrent;
	private TOTorrentAnnounceURLSet[]		sets;
	
	protected
	TOTorrentAnnounceURLGroupImpl(
		TOTorrentImpl	_torrent )
	{
		torrent	= _torrent;
		
		sets = new TOTorrentAnnounceURLSet[0];
	}

	protected void
	addSet(
		TOTorrentAnnounceURLSet	set )
	{
		TOTorrentAnnounceURLSet[]	new_sets = new TOTorrentAnnounceURLSet[sets.length+1];
		
		System.arraycopy( sets, 0, new_sets, 0, sets.length );
		
		new_sets[new_sets.length-1] = set;
		
		sets = new_sets;
	}
	
	public TOTorrentAnnounceURLSet[]
	getAnnounceURLSets()
	{
		return( sets );
	}
	
	public void
	setAnnounceURLSets(
		TOTorrentAnnounceURLSet[]	_sets )
	{
		sets = _sets;	
	}
		
	
	public TOTorrentAnnounceURLSet
	createAnnounceURLSet(
		URL[]	urls )
	{
		return( new TOTorrentAnnounceURLSetImpl( torrent, urls ));	
	}
	
}
